"""This file was generated by xsdata, v25.4, on 2025-05-13 09:06:38

Generator: PydanticGenerator
See: https://xsdata.readthedocs.io/
"""

from pyosis.generated.osis_core_2_1_1 import (
    AbbrCt,
    ACt,
    ActorCt,
    Calendar,
    CaptionCt,
    CastGroupCt,
    CastItemCt,
    CastListCt,
    CatchWordCt,
    CellCt,
    ChapterCt,
    CloserCt,
    ContributorCt,
    CorpusHeaderCt,
    CoverageCt,
    CreatorCt,
    DateCt,
    DescriptionCt,
    DivCt,
    DivineNameCt,
    FigureCt,
    ForeignCt,
    FormatCt,
    HeadCt,
    HeaderCt,
    HiCt,
    IdentifierCt,
    IndexCt,
    InscriptionCt,
    ItemCt,
    LabelCt,
    LanguageCt,
    LbCt,
    LCt,
    LgCt,
    ListCt,
    MentionedCt,
    Milestoneable,
    MilestoneCt,
    MilestoneEndCt,
    MilestoneSe,
    MilestoneStartCt,
    NameCt,
    NoteCt,
    Osis,
    OsisAnnotation,
    OsisCellAlign,
    OsisChanges,
    OsisCorpusCt,
    OsisCt,
    OsisDescription,
    OsisDivs,
    OsisEvents,
    OsisHi,
    OsisIdentifier,
    OsisLanguage,
    OsisLanguageUsage,
    OsisLine,
    OsisMilestonePt,
    OsisNames,
    OsisNotes,
    OsisPlacementNote,
    OsisPlacementTitle,
    OsisQuotes,
    OsisRdg,
    OsisReferences,
    OsisRoles,
    OsisSegs,
    OsisSubjects,
    OsisTextCt,
    OsisTitles,
    OsisType,
    PCt,
    PublisherCt,
    QCt,
    RdgCt,
    RdgGrpCt,
    ReferenceCt,
    RefSystemCt,
    RelationCt,
    RevisionDescCt,
    RightsCt,
    RoleCt,
    RoleDescCt,
    RowCt,
    SaluteCt,
    ScopeCt,
    SegCt,
    SignedCt,
    SourceCt,
    SpeakerCt,
    SpeechCt,
    SubjectCt,
    TableCt,
    TableRole,
    TeiHeaderCt,
    TitleCt,
    TitlePageCt,
    TransChangeCt,
    TypeCt,
    VerseCt,
    WCt,
    WorkCt,
    WorkPrefixCt,
)
from pyosis.generated.xml import (
    LangValue,
    SpaceValue,
)

__all__ = [
    "ACt",
    "AbbrCt",
    "ActorCt",
    "Calendar",
    "CaptionCt",
    "CastGroupCt",
    "CastItemCt",
    "CastListCt",
    "CatchWordCt",
    "CellCt",
    "ChapterCt",
    "CloserCt",
    "ContributorCt",
    "CorpusHeaderCt",
    "CoverageCt",
    "CreatorCt",
    "DateCt",
    "DescriptionCt",
    "DivCt",
    "DivineNameCt",
    "FigureCt",
    "ForeignCt",
    "FormatCt",
    "HeadCt",
    "HeaderCt",
    "HiCt",
    "IdentifierCt",
    "IndexCt",
    "InscriptionCt",
    "ItemCt",
    "LCt",
    "LabelCt",
    "LangValue",
    "LanguageCt",
    "LbCt",
    "LgCt",
    "ListCt",
    "MentionedCt",
    "MilestoneCt",
    "MilestoneEndCt",
    "MilestoneSe",
    "MilestoneStartCt",
    "Milestoneable",
    "NameCt",
    "NoteCt",
    "Osis",
    "OsisAnnotation",
    "OsisCellAlign",
    "OsisChanges",
    "OsisCorpusCt",
    "OsisCt",
    "OsisDescription",
    "OsisDivs",
    "OsisEvents",
    "OsisHi",
    "OsisIdentifier",
    "OsisLanguage",
    "OsisLanguageUsage",
    "OsisLine",
    "OsisMilestonePt",
    "OsisNames",
    "OsisNotes",
    "OsisPlacementNote",
    "OsisPlacementTitle",
    "OsisQuotes",
    "OsisRdg",
    "OsisReferences",
    "OsisRoles",
    "OsisSegs",
    "OsisSubjects",
    "OsisTextCt",
    "OsisTitles",
    "OsisType",
    "PCt",
    "PublisherCt",
    "QCt",
    "RdgCt",
    "RdgGrpCt",
    "RefSystemCt",
    "ReferenceCt",
    "RelationCt",
    "RevisionDescCt",
    "RightsCt",
    "RoleCt",
    "RoleDescCt",
    "RowCt",
    "SaluteCt",
    "ScopeCt",
    "SegCt",
    "SignedCt",
    "SourceCt",
    "SpaceValue",
    "SpeakerCt",
    "SpeechCt",
    "SubjectCt",
    "TableCt",
    "TableRole",
    "TeiHeaderCt",
    "TitleCt",
    "TitlePageCt",
    "TransChangeCt",
    "TypeCt",
    "VerseCt",
    "WCt",
    "WorkCt",
    "WorkPrefixCt",
]
