"""This file was generated by xsdata, v25.4, on 2025-05-13 09:06:38

Generator: PydanticGenerator
See: https://xsdata.readthedocs.io/
"""

from enum import Enum

__NAMESPACE__ = "http://www.w3.org/XML/1998/namespace"


class LangValue(Enum):
    VALUE = ""


class SpaceValue(Enum):
    DEFAULT = "default"
    PRESERVE = "preserve"
