"""Python tools for serializing and using OSIS files."""

__version__ = "0.2.0"

# ruff: noqa: F403

from pyosis import generated as generated
from pyosis.generated import *
from pyosis.serialization import OsisXML as OsisXML
